// DO NOT EDIT THIS FILE. IT WAS AUTOMATICALLY GENERATED BY:
//
//  ucd-generate property-values /home/andrew/tmp/ucd/12.1.0/
//
// ucd-generate is available on crates.io.

pub const PROPERTY_VALUES: &'static [(&'static str, &'static [(&'static str, &'static str)])] = &[
  ("ASCII_Hex_Digit", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Age", &[("1.1", "V1_1"), ("10.0", "V10_0"), ("11.0", "V11_0"),
  ("12.0", "V12_0"), ("12.1", "V12_1"), ("2.0", "V2_0"), ("2.1", "V2_1"),
  ("3.0", "V3_0"), ("3.1", "V3_1"), ("3.2", "V3_2"), ("4.0", "V4_0"),
  ("4.1", "V4_1"), ("5.0", "V5_0"), ("5.1", "V5_1"), ("5.2", "V5_2"),
  ("6.0", "V6_0"), ("6.1", "V6_1"), ("6.2", "V6_2"), ("6.3", "V6_3"),
  ("7.0", "V7_0"), ("8.0", "V8_0"), ("9.0", "V9_0"), ("na", "Unassigned"),
  ("unassigned", "Unassigned"), ("v100", "V10_0"), ("v11", "V1_1"),
  ("v110", "V11_0"), ("v120", "V12_0"), ("v121", "V12_1"), ("v20", "V2_0"),
  ("v21", "V2_1"), ("v30", "V3_0"), ("v31", "V3_1"), ("v32", "V3_2"),
  ("v40", "V4_0"), ("v41", "V4_1"), ("v50", "V5_0"), ("v51", "V5_1"),
  ("v52", "V5_2"), ("v60", "V6_0"), ("v61", "V6_1"), ("v62", "V6_2"),
  ("v63", "V6_3"), ("v70", "V7_0"), ("v80", "V8_0"), ("v90", "V9_0"), ]),

  ("Alphabetic", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Bidi_Class", &[("al", "Arabic_Letter"), ("an", "Arabic_Number"),
  ("arabicletter", "Arabic_Letter"), ("arabicnumber", "Arabic_Number"),
  ("b", "Paragraph_Separator"), ("bn", "Boundary_Neutral"),
  ("boundaryneutral", "Boundary_Neutral"),
  ("commonseparator", "Common_Separator"), ("cs", "Common_Separator"),
  ("en", "European_Number"), ("es", "European_Separator"),
  ("et", "European_Terminator"), ("europeannumber", "European_Number"),
  ("europeanseparator", "European_Separator"),
  ("europeanterminator", "European_Terminator"),
  ("firststrongisolate", "First_Strong_Isolate"),
  ("fsi", "First_Strong_Isolate"), ("l", "Left_To_Right"),
  ("lefttoright", "Left_To_Right"),
  ("lefttorightembedding", "Left_To_Right_Embedding"),
  ("lefttorightisolate", "Left_To_Right_Isolate"),
  ("lefttorightoverride", "Left_To_Right_Override"),
  ("lre", "Left_To_Right_Embedding"), ("lri", "Left_To_Right_Isolate"),
  ("lro", "Left_To_Right_Override"), ("nonspacingmark", "Nonspacing_Mark"),
  ("nsm", "Nonspacing_Mark"), ("on", "Other_Neutral"),
  ("otherneutral", "Other_Neutral"),
  ("paragraphseparator", "Paragraph_Separator"),
  ("pdf", "Pop_Directional_Format"), ("pdi", "Pop_Directional_Isolate"),
  ("popdirectionalformat", "Pop_Directional_Format"),
  ("popdirectionalisolate", "Pop_Directional_Isolate"),
  ("r", "Right_To_Left"), ("righttoleft", "Right_To_Left"),
  ("righttoleftembedding", "Right_To_Left_Embedding"),
  ("righttoleftisolate", "Right_To_Left_Isolate"),
  ("righttoleftoverride", "Right_To_Left_Override"),
  ("rle", "Right_To_Left_Embedding"), ("rli", "Right_To_Left_Isolate"),
  ("rlo", "Right_To_Left_Override"), ("s", "Segment_Separator"),
  ("segmentseparator", "Segment_Separator"), ("whitespace", "White_Space"),
  ("ws", "White_Space"), ]),

  ("Bidi_Control", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Bidi_Mirrored", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Bidi_Paired_Bracket_Type", &[("c", "Close"), ("close", "Close"),
  ("n", "None"), ("none", "None"), ("o", "Open"), ("open", "Open"), ]),

  ("Block", &[("adlam", "Adlam"), ("aegeannumbers", "Aegean_Numbers"),
  ("ahom", "Ahom"), ("alchemical", "Alchemical_Symbols"),
  ("alchemicalsymbols", "Alchemical_Symbols"),
  ("alphabeticpf", "Alphabetic_Presentation_Forms"),
  ("alphabeticpresentationforms", "Alphabetic_Presentation_Forms"),
  ("anatolianhieroglyphs", "Anatolian_Hieroglyphs"),
  ("ancientgreekmusic", "Ancient_Greek_Musical_Notation"),
  ("ancientgreekmusicalnotation", "Ancient_Greek_Musical_Notation"),
  ("ancientgreeknumbers", "Ancient_Greek_Numbers"),
  ("ancientsymbols", "Ancient_Symbols"), ("arabic", "Arabic"),
  ("arabicexta", "Arabic_Extended_A"),
  ("arabicextendeda", "Arabic_Extended_A"),
  ("arabicmath", "Arabic_Mathematical_Alphabetic_Symbols"),
  ("arabicmathematicalalphabeticsymbols", "Arabic_Mathematical_Alphabetic_Symbols"),
  ("arabicpfa", "Arabic_Presentation_Forms_A"),
  ("arabicpfb", "Arabic_Presentation_Forms_B"),
  ("arabicpresentationformsa", "Arabic_Presentation_Forms_A"),
  ("arabicpresentationformsb", "Arabic_Presentation_Forms_B"),
  ("arabicsup", "Arabic_Supplement"),
  ("arabicsupplement", "Arabic_Supplement"), ("armenian", "Armenian"),
  ("arrows", "Arrows"), ("ascii", "Basic_Latin"), ("avestan", "Avestan"),
  ("balinese", "Balinese"), ("bamum", "Bamum"),
  ("bamumsup", "Bamum_Supplement"), ("bamumsupplement", "Bamum_Supplement"),
  ("basiclatin", "Basic_Latin"), ("bassavah", "Bassa_Vah"),
  ("batak", "Batak"), ("bengali", "Bengali"), ("bhaiksuki", "Bhaiksuki"),
  ("blockelements", "Block_Elements"), ("bopomofo", "Bopomofo"),
  ("bopomofoext", "Bopomofo_Extended"),
  ("bopomofoextended", "Bopomofo_Extended"), ("boxdrawing", "Box_Drawing"),
  ("brahmi", "Brahmi"), ("braille", "Braille_Patterns"),
  ("braillepatterns", "Braille_Patterns"), ("buginese", "Buginese"),
  ("buhid", "Buhid"), ("byzantinemusic", "Byzantine_Musical_Symbols"),
  ("byzantinemusicalsymbols", "Byzantine_Musical_Symbols"),
  ("canadiansyllabics", "Unified_Canadian_Aboriginal_Syllabics"),
  ("carian", "Carian"), ("caucasianalbanian", "Caucasian_Albanian"),
  ("chakma", "Chakma"), ("cham", "Cham"), ("cherokee", "Cherokee"),
  ("cherokeesup", "Cherokee_Supplement"),
  ("cherokeesupplement", "Cherokee_Supplement"),
  ("chesssymbols", "Chess_Symbols"), ("cjk", "CJK_Unified_Ideographs"),
  ("cjkcompat", "CJK_Compatibility"),
  ("cjkcompatforms", "CJK_Compatibility_Forms"),
  ("cjkcompatibility", "CJK_Compatibility"),
  ("cjkcompatibilityforms", "CJK_Compatibility_Forms"),
  ("cjkcompatibilityideographs", "CJK_Compatibility_Ideographs"),
  ("cjkcompatibilityideographssupplement", "CJK_Compatibility_Ideographs_Supplement"),
  ("cjkcompatideographs", "CJK_Compatibility_Ideographs"),
  ("cjkcompatideographssup", "CJK_Compatibility_Ideographs_Supplement"),
  ("cjkexta", "CJK_Unified_Ideographs_Extension_A"),
  ("cjkextb", "CJK_Unified_Ideographs_Extension_B"),
  ("cjkextc", "CJK_Unified_Ideographs_Extension_C"),
  ("cjkextd", "CJK_Unified_Ideographs_Extension_D"),
  ("cjkexte", "CJK_Unified_Ideographs_Extension_E"),
  ("cjkextf", "CJK_Unified_Ideographs_Extension_F"),
  ("cjkradicalssup", "CJK_Radicals_Supplement"),
  ("cjkradicalssupplement", "CJK_Radicals_Supplement"),
  ("cjkstrokes", "CJK_Strokes"),
  ("cjksymbols", "CJK_Symbols_And_Punctuation"),
  ("cjksymbolsandpunctuation", "CJK_Symbols_And_Punctuation"),
  ("cjkunifiedideographs", "CJK_Unified_Ideographs"),
  ("cjkunifiedideographsextensiona", "CJK_Unified_Ideographs_Extension_A"),
  ("cjkunifiedideographsextensionb", "CJK_Unified_Ideographs_Extension_B"),
  ("cjkunifiedideographsextensionc", "CJK_Unified_Ideographs_Extension_C"),
  ("cjkunifiedideographsextensiond", "CJK_Unified_Ideographs_Extension_D"),
  ("cjkunifiedideographsextensione", "CJK_Unified_Ideographs_Extension_E"),
  ("cjkunifiedideographsextensionf", "CJK_Unified_Ideographs_Extension_F"),
  ("combiningdiacriticalmarks", "Combining_Diacritical_Marks"),
  ("combiningdiacriticalmarksextended", "Combining_Diacritical_Marks_Extended"),
  ("combiningdiacriticalmarksforsymbols", "Combining_Diacritical_Marks_For_Symbols"),
  ("combiningdiacriticalmarkssupplement", "Combining_Diacritical_Marks_Supplement"),
  ("combininghalfmarks", "Combining_Half_Marks"),
  ("combiningmarksforsymbols", "Combining_Diacritical_Marks_For_Symbols"),
  ("commonindicnumberforms", "Common_Indic_Number_Forms"),
  ("compatjamo", "Hangul_Compatibility_Jamo"),
  ("controlpictures", "Control_Pictures"), ("coptic", "Coptic"),
  ("copticepactnumbers", "Coptic_Epact_Numbers"),
  ("countingrod", "Counting_Rod_Numerals"),
  ("countingrodnumerals", "Counting_Rod_Numerals"),
  ("cuneiform", "Cuneiform"),
  ("cuneiformnumbers", "Cuneiform_Numbers_And_Punctuation"),
  ("cuneiformnumbersandpunctuation", "Cuneiform_Numbers_And_Punctuation"),
  ("currencysymbols", "Currency_Symbols"),
  ("cypriotsyllabary", "Cypriot_Syllabary"), ("cyrillic", "Cyrillic"),
  ("cyrillicexta", "Cyrillic_Extended_A"),
  ("cyrillicextb", "Cyrillic_Extended_B"),
  ("cyrillicextc", "Cyrillic_Extended_C"),
  ("cyrillicextendeda", "Cyrillic_Extended_A"),
  ("cyrillicextendedb", "Cyrillic_Extended_B"),
  ("cyrillicextendedc", "Cyrillic_Extended_C"),
  ("cyrillicsup", "Cyrillic_Supplement"),
  ("cyrillicsupplement", "Cyrillic_Supplement"),
  ("cyrillicsupplementary", "Cyrillic_Supplement"), ("deseret", "Deseret"),
  ("devanagari", "Devanagari"), ("devanagariext", "Devanagari_Extended"),
  ("devanagariextended", "Devanagari_Extended"),
  ("diacriticals", "Combining_Diacritical_Marks"),
  ("diacriticalsext", "Combining_Diacritical_Marks_Extended"),
  ("diacriticalsforsymbols", "Combining_Diacritical_Marks_For_Symbols"),
  ("diacriticalssup", "Combining_Diacritical_Marks_Supplement"),
  ("dingbats", "Dingbats"), ("dogra", "Dogra"), ("domino", "Domino_Tiles"),
  ("dominotiles", "Domino_Tiles"), ("duployan", "Duployan"),
  ("earlydynasticcuneiform", "Early_Dynastic_Cuneiform"),
  ("egyptianhieroglyphformatcontrols", "Egyptian_Hieroglyph_Format_Controls"),
  ("egyptianhieroglyphs", "Egyptian_Hieroglyphs"), ("elbasan", "Elbasan"),
  ("elymaic", "Elymaic"), ("emoticons", "Emoticons"),
  ("enclosedalphanum", "Enclosed_Alphanumerics"),
  ("enclosedalphanumerics", "Enclosed_Alphanumerics"),
  ("enclosedalphanumericsupplement", "Enclosed_Alphanumeric_Supplement"),
  ("enclosedalphanumsup", "Enclosed_Alphanumeric_Supplement"),
  ("enclosedcjk", "Enclosed_CJK_Letters_And_Months"),
  ("enclosedcjklettersandmonths", "Enclosed_CJK_Letters_And_Months"),
  ("enclosedideographicsup", "Enclosed_Ideographic_Supplement"),
  ("enclosedideographicsupplement", "Enclosed_Ideographic_Supplement"),
  ("ethiopic", "Ethiopic"), ("ethiopicext", "Ethiopic_Extended"),
  ("ethiopicexta", "Ethiopic_Extended_A"),
  ("ethiopicextended", "Ethiopic_Extended"),
  ("ethiopicextendeda", "Ethiopic_Extended_A"),
  ("ethiopicsup", "Ethiopic_Supplement"),
  ("ethiopicsupplement", "Ethiopic_Supplement"),
  ("generalpunctuation", "General_Punctuation"),
  ("geometricshapes", "Geometric_Shapes"),
  ("geometricshapesext", "Geometric_Shapes_Extended"),
  ("geometricshapesextended", "Geometric_Shapes_Extended"),
  ("georgian", "Georgian"), ("georgianext", "Georgian_Extended"),
  ("georgianextended", "Georgian_Extended"),
  ("georgiansup", "Georgian_Supplement"),
  ("georgiansupplement", "Georgian_Supplement"), ("glagolitic", "Glagolitic"),
  ("glagoliticsup", "Glagolitic_Supplement"),
  ("glagoliticsupplement", "Glagolitic_Supplement"), ("gothic", "Gothic"),
  ("grantha", "Grantha"), ("greek", "Greek_And_Coptic"),
  ("greekandcoptic", "Greek_And_Coptic"), ("greekext", "Greek_Extended"),
  ("greekextended", "Greek_Extended"), ("gujarati", "Gujarati"),
  ("gunjalagondi", "Gunjala_Gondi"), ("gurmukhi", "Gurmukhi"),
  ("halfandfullforms", "Halfwidth_And_Fullwidth_Forms"),
  ("halfmarks", "Combining_Half_Marks"),
  ("halfwidthandfullwidthforms", "Halfwidth_And_Fullwidth_Forms"),
  ("hangul", "Hangul_Syllables"),
  ("hangulcompatibilityjamo", "Hangul_Compatibility_Jamo"),
  ("hanguljamo", "Hangul_Jamo"),
  ("hanguljamoextendeda", "Hangul_Jamo_Extended_A"),
  ("hanguljamoextendedb", "Hangul_Jamo_Extended_B"),
  ("hangulsyllables", "Hangul_Syllables"),
  ("hanifirohingya", "Hanifi_Rohingya"), ("hanunoo", "Hanunoo"),
  ("hatran", "Hatran"), ("hebrew", "Hebrew"),
  ("highprivateusesurrogates", "High_Private_Use_Surrogates"),
  ("highpusurrogates", "High_Private_Use_Surrogates"),
  ("highsurrogates", "High_Surrogates"), ("hiragana", "Hiragana"),
  ("idc", "Ideographic_Description_Characters"),
  ("ideographicdescriptioncharacters", "Ideographic_Description_Characters"),
  ("ideographicsymbols", "Ideographic_Symbols_And_Punctuation"),
  ("ideographicsymbolsandpunctuation", "Ideographic_Symbols_And_Punctuation"),
  ("imperialaramaic", "Imperial_Aramaic"),
  ("indicnumberforms", "Common_Indic_Number_Forms"),
  ("indicsiyaqnumbers", "Indic_Siyaq_Numbers"),
  ("inscriptionalpahlavi", "Inscriptional_Pahlavi"),
  ("inscriptionalparthian", "Inscriptional_Parthian"),
  ("ipaext", "IPA_Extensions"), ("ipaextensions", "IPA_Extensions"),
  ("jamo", "Hangul_Jamo"), ("jamoexta", "Hangul_Jamo_Extended_A"),
  ("jamoextb", "Hangul_Jamo_Extended_B"), ("javanese", "Javanese"),
  ("kaithi", "Kaithi"), ("kanaexta", "Kana_Extended_A"),
  ("kanaextendeda", "Kana_Extended_A"), ("kanasup", "Kana_Supplement"),
  ("kanasupplement", "Kana_Supplement"), ("kanbun", "Kanbun"),
  ("kangxi", "Kangxi_Radicals"), ("kangxiradicals", "Kangxi_Radicals"),
  ("kannada", "Kannada"), ("katakana", "Katakana"),
  ("katakanaext", "Katakana_Phonetic_Extensions"),
  ("katakanaphoneticextensions", "Katakana_Phonetic_Extensions"),
  ("kayahli", "Kayah_Li"), ("kharoshthi", "Kharoshthi"), ("khmer", "Khmer"),
  ("khmersymbols", "Khmer_Symbols"), ("khojki", "Khojki"),
  ("khudawadi", "Khudawadi"), ("lao", "Lao"),
  ("latin1", "Latin_1_Supplement"), ("latin1sup", "Latin_1_Supplement"),
  ("latin1supplement", "Latin_1_Supplement"),
  ("latinexta", "Latin_Extended_A"),
  ("latinextadditional", "Latin_Extended_Additional"),
  ("latinextb", "Latin_Extended_B"), ("latinextc", "Latin_Extended_C"),
  ("latinextd", "Latin_Extended_D"), ("latinexte", "Latin_Extended_E"),
  ("latinextendeda", "Latin_Extended_A"),
  ("latinextendedadditional", "Latin_Extended_Additional"),
  ("latinextendedb", "Latin_Extended_B"),
  ("latinextendedc", "Latin_Extended_C"),
  ("latinextendedd", "Latin_Extended_D"),
  ("latinextendede", "Latin_Extended_E"), ("lepcha", "Lepcha"),
  ("letterlikesymbols", "Letterlike_Symbols"), ("limbu", "Limbu"),
  ("lineara", "Linear_A"), ("linearbideograms", "Linear_B_Ideograms"),
  ("linearbsyllabary", "Linear_B_Syllabary"), ("lisu", "Lisu"),
  ("lowsurrogates", "Low_Surrogates"), ("lycian", "Lycian"),
  ("lydian", "Lydian"), ("mahajani", "Mahajani"),
  ("mahjong", "Mahjong_Tiles"), ("mahjongtiles", "Mahjong_Tiles"),
  ("makasar", "Makasar"), ("malayalam", "Malayalam"), ("mandaic", "Mandaic"),
  ("manichaean", "Manichaean"), ("marchen", "Marchen"),
  ("masaramgondi", "Masaram_Gondi"),
  ("mathalphanum", "Mathematical_Alphanumeric_Symbols"),
  ("mathematicalalphanumericsymbols", "Mathematical_Alphanumeric_Symbols"),
  ("mathematicaloperators", "Mathematical_Operators"),
  ("mathoperators", "Mathematical_Operators"),
  ("mayannumerals", "Mayan_Numerals"), ("medefaidrin", "Medefaidrin"),
  ("meeteimayek", "Meetei_Mayek"),
  ("meeteimayekext", "Meetei_Mayek_Extensions"),
  ("meeteimayekextensions", "Meetei_Mayek_Extensions"),
  ("mendekikakui", "Mende_Kikakui"), ("meroiticcursive", "Meroitic_Cursive"),
  ("meroitichieroglyphs", "Meroitic_Hieroglyphs"), ("miao", "Miao"),
  ("miscarrows", "Miscellaneous_Symbols_And_Arrows"),
  ("miscellaneousmathematicalsymbolsa", "Miscellaneous_Mathematical_Symbols_A"),
  ("miscellaneousmathematicalsymbolsb", "Miscellaneous_Mathematical_Symbols_B"),
  ("miscellaneoussymbols", "Miscellaneous_Symbols"),
  ("miscellaneoussymbolsandarrows", "Miscellaneous_Symbols_And_Arrows"),
  ("miscellaneoussymbolsandpictographs", "Miscellaneous_Symbols_And_Pictographs"),
  ("miscellaneoustechnical", "Miscellaneous_Technical"),
  ("miscmathsymbolsa", "Miscellaneous_Mathematical_Symbols_A"),
  ("miscmathsymbolsb", "Miscellaneous_Mathematical_Symbols_B"),
  ("miscpictographs", "Miscellaneous_Symbols_And_Pictographs"),
  ("miscsymbols", "Miscellaneous_Symbols"),
  ("misctechnical", "Miscellaneous_Technical"), ("modi", "Modi"),
  ("modifierletters", "Spacing_Modifier_Letters"),
  ("modifiertoneletters", "Modifier_Tone_Letters"),
  ("mongolian", "Mongolian"), ("mongoliansup", "Mongolian_Supplement"),
  ("mongoliansupplement", "Mongolian_Supplement"), ("mro", "Mro"),
  ("multani", "Multani"), ("music", "Musical_Symbols"),
  ("musicalsymbols", "Musical_Symbols"), ("myanmar", "Myanmar"),
  ("myanmarexta", "Myanmar_Extended_A"),
  ("myanmarextb", "Myanmar_Extended_B"),
  ("myanmarextendeda", "Myanmar_Extended_A"),
  ("myanmarextendedb", "Myanmar_Extended_B"), ("nabataean", "Nabataean"),
  ("nandinagari", "Nandinagari"), ("nb", "No_Block"), ("newa", "Newa"),
  ("newtailue", "New_Tai_Lue"), ("nko", "NKo"), ("noblock", "No_Block"),
  ("numberforms", "Number_Forms"), ("nushu", "Nushu"),
  ("nyiakengpuachuehmong", "Nyiakeng_Puachue_Hmong"),
  ("ocr", "Optical_Character_Recognition"), ("ogham", "Ogham"),
  ("olchiki", "Ol_Chiki"), ("oldhungarian", "Old_Hungarian"),
  ("olditalic", "Old_Italic"), ("oldnortharabian", "Old_North_Arabian"),
  ("oldpermic", "Old_Permic"), ("oldpersian", "Old_Persian"),
  ("oldsogdian", "Old_Sogdian"), ("oldsoutharabian", "Old_South_Arabian"),
  ("oldturkic", "Old_Turkic"),
  ("opticalcharacterrecognition", "Optical_Character_Recognition"),
  ("oriya", "Oriya"), ("ornamentaldingbats", "Ornamental_Dingbats"),
  ("osage", "Osage"), ("osmanya", "Osmanya"),
  ("ottomansiyaqnumbers", "Ottoman_Siyaq_Numbers"),
  ("pahawhhmong", "Pahawh_Hmong"), ("palmyrene", "Palmyrene"),
  ("paucinhau", "Pau_Cin_Hau"), ("phagspa", "Phags_Pa"),
  ("phaistos", "Phaistos_Disc"), ("phaistosdisc", "Phaistos_Disc"),
  ("phoenician", "Phoenician"), ("phoneticext", "Phonetic_Extensions"),
  ("phoneticextensions", "Phonetic_Extensions"),
  ("phoneticextensionssupplement", "Phonetic_Extensions_Supplement"),
  ("phoneticextsup", "Phonetic_Extensions_Supplement"),
  ("playingcards", "Playing_Cards"), ("privateuse", "Private_Use_Area"),
  ("privateusearea", "Private_Use_Area"),
  ("psalterpahlavi", "Psalter_Pahlavi"), ("pua", "Private_Use_Area"),
  ("punctuation", "General_Punctuation"), ("rejang", "Rejang"),
  ("rumi", "Rumi_Numeral_Symbols"),
  ("ruminumeralsymbols", "Rumi_Numeral_Symbols"), ("runic", "Runic"),
  ("samaritan", "Samaritan"), ("saurashtra", "Saurashtra"),
  ("sharada", "Sharada"), ("shavian", "Shavian"),
  ("shorthandformatcontrols", "Shorthand_Format_Controls"),
  ("siddham", "Siddham"), ("sinhala", "Sinhala"),
  ("sinhalaarchaicnumbers", "Sinhala_Archaic_Numbers"),
  ("smallforms", "Small_Form_Variants"),
  ("smallformvariants", "Small_Form_Variants"),
  ("smallkanaext", "Small_Kana_Extension"),
  ("smallkanaextension", "Small_Kana_Extension"), ("sogdian", "Sogdian"),
  ("sorasompeng", "Sora_Sompeng"), ("soyombo", "Soyombo"),
  ("spacingmodifierletters", "Spacing_Modifier_Letters"),
  ("specials", "Specials"), ("sundanese", "Sundanese"),
  ("sundanesesup", "Sundanese_Supplement"),
  ("sundanesesupplement", "Sundanese_Supplement"),
  ("suparrowsa", "Supplemental_Arrows_A"),
  ("suparrowsb", "Supplemental_Arrows_B"),
  ("suparrowsc", "Supplemental_Arrows_C"),
  ("superandsub", "Superscripts_And_Subscripts"),
  ("superscriptsandsubscripts", "Superscripts_And_Subscripts"),
  ("supmathoperators", "Supplemental_Mathematical_Operators"),
  ("supplementalarrowsa", "Supplemental_Arrows_A"),
  ("supplementalarrowsb", "Supplemental_Arrows_B"),
  ("supplementalarrowsc", "Supplemental_Arrows_C"),
  ("supplementalmathematicaloperators", "Supplemental_Mathematical_Operators"),
  ("supplementalpunctuation", "Supplemental_Punctuation"),
  ("supplementalsymbolsandpictographs", "Supplemental_Symbols_And_Pictographs"),
  ("supplementaryprivateuseareaa", "Supplementary_Private_Use_Area_A"),
  ("supplementaryprivateuseareab", "Supplementary_Private_Use_Area_B"),
  ("suppuaa", "Supplementary_Private_Use_Area_A"),
  ("suppuab", "Supplementary_Private_Use_Area_B"),
  ("suppunctuation", "Supplemental_Punctuation"),
  ("supsymbolsandpictographs", "Supplemental_Symbols_And_Pictographs"),
  ("suttonsignwriting", "Sutton_SignWriting"),
  ("sylotinagri", "Syloti_Nagri"),
  ("symbolsandpictographsexta", "Symbols_And_Pictographs_Extended_A"),
  ("symbolsandpictographsextendeda", "Symbols_And_Pictographs_Extended_A"),
  ("syriac", "Syriac"), ("syriacsup", "Syriac_Supplement"),
  ("syriacsupplement", "Syriac_Supplement"), ("tagalog", "Tagalog"),
  ("tagbanwa", "Tagbanwa"), ("tags", "Tags"), ("taile", "Tai_Le"),
  ("taitham", "Tai_Tham"), ("taiviet", "Tai_Viet"),
  ("taixuanjing", "Tai_Xuan_Jing_Symbols"),
  ("taixuanjingsymbols", "Tai_Xuan_Jing_Symbols"), ("takri", "Takri"),
  ("tamil", "Tamil"), ("tamilsup", "Tamil_Supplement"),
  ("tamilsupplement", "Tamil_Supplement"), ("tangut", "Tangut"),
  ("tangutcomponents", "Tangut_Components"), ("telugu", "Telugu"),
  ("thaana", "Thaana"), ("thai", "Thai"), ("tibetan", "Tibetan"),
  ("tifinagh", "Tifinagh"), ("tirhuta", "Tirhuta"),
  ("transportandmap", "Transport_And_Map_Symbols"),
  ("transportandmapsymbols", "Transport_And_Map_Symbols"),
  ("ucas", "Unified_Canadian_Aboriginal_Syllabics"),
  ("ucasext", "Unified_Canadian_Aboriginal_Syllabics_Extended"),
  ("ugaritic", "Ugaritic"),
  ("unifiedcanadianaboriginalsyllabics", "Unified_Canadian_Aboriginal_Syllabics"),
  ("unifiedcanadianaboriginalsyllabicsextended", "Unified_Canadian_Aboriginal_Syllabics_Extended"),
  ("vai", "Vai"), ("variationselectors", "Variation_Selectors"),
  ("variationselectorssupplement", "Variation_Selectors_Supplement"),
  ("vedicext", "Vedic_Extensions"), ("vedicextensions", "Vedic_Extensions"),
  ("verticalforms", "Vertical_Forms"), ("vs", "Variation_Selectors"),
  ("vssup", "Variation_Selectors_Supplement"), ("wancho", "Wancho"),
  ("warangciti", "Warang_Citi"), ("yijing", "Yijing_Hexagram_Symbols"),
  ("yijinghexagramsymbols", "Yijing_Hexagram_Symbols"),
  ("yiradicals", "Yi_Radicals"), ("yisyllables", "Yi_Syllables"),
  ("zanabazarsquare", "Zanabazar_Square"), ]),

  ("Canonical_Combining_Class", &[("", "Iota_Subscript"),
  ("0", "Not_Reordered"), ("1", "Overlay"), ("10", "CCC10"),
  ("103", "CCC103"), ("107", "CCC107"), ("11", "CCC11"), ("118", "CCC118"),
  ("12", "CCC12"), ("122", "CCC122"), ("129", "CCC129"), ("13", "CCC13"),
  ("130", "CCC130"), ("132", "CCC132"), ("133", "CCC133"), ("14", "CCC14"),
  ("15", "CCC15"), ("16", "CCC16"), ("17", "CCC17"), ("18", "CCC18"),
  ("19", "CCC19"), ("20", "CCC20"), ("200", "Attached_Below_Left"),
  ("202", "Attached_Below"), ("21", "CCC21"), ("214", "Attached_Above"),
  ("216", "Attached_Above_Right"), ("218", "Below_Left"), ("22", "CCC22"),
  ("220", "Below"), ("222", "Below_Right"), ("224", "Left"), ("226", "Right"),
  ("228", "Above_Left"), ("23", "CCC23"), ("230", "Above"),
  ("232", "Above_Right"), ("233", "Double_Below"), ("234", "Double_Above"),
  ("24", "CCC24"), ("240", "Iota_Subscript"), ("25", "CCC25"),
  ("26", "CCC26"), ("27", "CCC27"), ("28", "CCC28"), ("29", "CCC29"),
  ("30", "CCC30"), ("31", "CCC31"), ("32", "CCC32"), ("33", "CCC33"),
  ("34", "CCC34"), ("35", "CCC35"), ("36", "CCC36"), ("7", "Nukta"),
  ("8", "Kana_Voicing"), ("84", "CCC84"), ("9", "Virama"), ("91", "CCC91"),
  ("a", "Above"), ("above", "Above"), ("aboveleft", "Above_Left"),
  ("aboveright", "Above_Right"), ("al", "Above_Left"), ("ar", "Above_Right"),
  ("ata", "Attached_Above"), ("atar", "Attached_Above_Right"),
  ("atb", "Attached_Below"), ("atbl", "Attached_Below_Left"),
  ("attachedabove", "Attached_Above"),
  ("attachedaboveright", "Attached_Above_Right"),
  ("attachedbelow", "Attached_Below"),
  ("attachedbelowleft", "Attached_Below_Left"), ("b", "Below"),
  ("below", "Below"), ("belowleft", "Below_Left"),
  ("belowright", "Below_Right"), ("bl", "Below_Left"), ("br", "Below_Right"),
  ("ccc10", "CCC10"), ("ccc103", "CCC103"), ("ccc107", "CCC107"),
  ("ccc11", "CCC11"), ("ccc118", "CCC118"), ("ccc12", "CCC12"),
  ("ccc122", "CCC122"), ("ccc129", "CCC129"), ("ccc13", "CCC13"),
  ("ccc130", "CCC130"), ("ccc132", "CCC132"), ("ccc133", "CCC133"),
  ("ccc14", "CCC14"), ("ccc15", "CCC15"), ("ccc16", "CCC16"),
  ("ccc17", "CCC17"), ("ccc18", "CCC18"), ("ccc19", "CCC19"),
  ("ccc20", "CCC20"), ("ccc21", "CCC21"), ("ccc22", "CCC22"),
  ("ccc23", "CCC23"), ("ccc24", "CCC24"), ("ccc25", "CCC25"),
  ("ccc26", "CCC26"), ("ccc27", "CCC27"), ("ccc28", "CCC28"),
  ("ccc29", "CCC29"), ("ccc30", "CCC30"), ("ccc31", "CCC31"),
  ("ccc32", "CCC32"), ("ccc33", "CCC33"), ("ccc34", "CCC34"),
  ("ccc35", "CCC35"), ("ccc36", "CCC36"), ("ccc84", "CCC84"),
  ("ccc91", "CCC91"), ("da", "Double_Above"), ("db", "Double_Below"),
  ("doubleabove", "Double_Above"), ("doublebelow", "Double_Below"),
  ("iotasubscript", "Iota_Subscript"), ("kanavoicing", "Kana_Voicing"),
  ("kv", "Kana_Voicing"), ("l", "Left"), ("left", "Left"), ("nk", "Nukta"),
  ("notreordered", "Not_Reordered"), ("nr", "Not_Reordered"),
  ("nukta", "Nukta"), ("ov", "Overlay"), ("overlay", "Overlay"),
  ("r", "Right"), ("right", "Right"), ("virama", "Virama"), ("vr", "Virama"),
  ]),

  ("Case_Ignorable", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Cased", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Changes_When_Casefolded", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Changes_When_Casemapped", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Changes_When_Lowercased", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Changes_When_NFKC_Casefolded", &[("f", "No"), ("false", "No"),
  ("n", "No"), ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"),
  ("yes", "Yes"), ]),

  ("Changes_When_Titlecased", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Changes_When_Uppercased", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Composition_Exclusion", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Dash", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Decomposition_Type", &[("can", "Canonical"), ("canonical", "Canonical"),
  ("circle", "Circle"), ("com", "Compat"), ("compat", "Compat"),
  ("enc", "Circle"), ("fin", "Final"), ("final", "Final"), ("font", "Font"),
  ("fra", "Fraction"), ("fraction", "Fraction"), ("init", "Initial"),
  ("initial", "Initial"), ("med", "Medial"), ("medial", "Medial"),
  ("nar", "Narrow"), ("narrow", "Narrow"), ("nb", "Nobreak"),
  ("nobreak", "Nobreak"), ("none", "None"), ("o", "Isolated"),
  ("olated", "Isolated"), ("small", "Small"), ("sml", "Small"),
  ("sqr", "Square"), ("square", "Square"), ("sub", "Sub"), ("sup", "Super"),
  ("super", "Super"), ("vert", "Vertical"), ("vertical", "Vertical"),
  ("wide", "Wide"), ]),

  ("Default_Ignorable_Code_Point", &[("f", "No"), ("false", "No"),
  ("n", "No"), ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"),
  ("yes", "Yes"), ]),

  ("Deprecated", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Diacritic", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("East_Asian_Width", &[("a", "Ambiguous"), ("ambiguous", "Ambiguous"),
  ("f", "Fullwidth"), ("fullwidth", "Fullwidth"), ("h", "Halfwidth"),
  ("halfwidth", "Halfwidth"), ("n", "Neutral"), ("na", "Narrow"),
  ("narrow", "Narrow"), ("neutral", "Neutral"), ("w", "Wide"),
  ("wide", "Wide"), ]),

  ("Expands_On_NFC", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Expands_On_NFD", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Expands_On_NFKC", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Expands_On_NFKD", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Extender", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Full_Composition_Exclusion", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("General_Category", &[("c", "Other"), ("casedletter", "Cased_Letter"),
  ("cc", "Control"), ("cf", "Format"),
  ("closepunctuation", "Close_Punctuation"), ("cn", "Unassigned"),
  ("cntrl", "Control"), ("co", "Private_Use"), ("combiningmark", "Mark"),
  ("connectorpunctuation", "Connector_Punctuation"), ("control", "Control"),
  ("cs", "Surrogate"), ("currencysymbol", "Currency_Symbol"),
  ("dashpunctuation", "Dash_Punctuation"),
  ("decimalnumber", "Decimal_Number"), ("digit", "Decimal_Number"),
  ("enclosingmark", "Enclosing_Mark"),
  ("finalpunctuation", "Final_Punctuation"), ("format", "Format"),
  ("initialpunctuation", "Initial_Punctuation"), ("l", "Letter"),
  ("lc", "Cased_Letter"), ("letter", "Letter"),
  ("letternumber", "Letter_Number"), ("lineseparator", "Line_Separator"),
  ("ll", "Lowercase_Letter"), ("lm", "Modifier_Letter"),
  ("lo", "Other_Letter"), ("lowercaseletter", "Lowercase_Letter"),
  ("lt", "Titlecase_Letter"), ("lu", "Uppercase_Letter"), ("m", "Mark"),
  ("mark", "Mark"), ("mathsymbol", "Math_Symbol"), ("mc", "Spacing_Mark"),
  ("me", "Enclosing_Mark"), ("mn", "Nonspacing_Mark"),
  ("modifierletter", "Modifier_Letter"),
  ("modifiersymbol", "Modifier_Symbol"), ("n", "Number"),
  ("nd", "Decimal_Number"), ("nl", "Letter_Number"), ("no", "Other_Number"),
  ("nonspacingmark", "Nonspacing_Mark"), ("number", "Number"),
  ("openpunctuation", "Open_Punctuation"), ("other", "Other"),
  ("otherletter", "Other_Letter"), ("othernumber", "Other_Number"),
  ("otherpunctuation", "Other_Punctuation"), ("othersymbol", "Other_Symbol"),
  ("p", "Punctuation"), ("paragraphseparator", "Paragraph_Separator"),
  ("pc", "Connector_Punctuation"), ("pd", "Dash_Punctuation"),
  ("pe", "Close_Punctuation"), ("pf", "Final_Punctuation"),
  ("pi", "Initial_Punctuation"), ("po", "Other_Punctuation"),
  ("privateuse", "Private_Use"), ("ps", "Open_Punctuation"),
  ("punct", "Punctuation"), ("punctuation", "Punctuation"), ("s", "Symbol"),
  ("sc", "Currency_Symbol"), ("separator", "Separator"),
  ("sk", "Modifier_Symbol"), ("sm", "Math_Symbol"), ("so", "Other_Symbol"),
  ("spaceseparator", "Space_Separator"), ("spacingmark", "Spacing_Mark"),
  ("surrogate", "Surrogate"), ("symbol", "Symbol"),
  ("titlecaseletter", "Titlecase_Letter"), ("unassigned", "Unassigned"),
  ("uppercaseletter", "Uppercase_Letter"), ("z", "Separator"),
  ("zl", "Line_Separator"), ("zp", "Paragraph_Separator"),
  ("zs", "Space_Separator"), ]),

  ("Grapheme_Base", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Grapheme_Cluster_Break", &[("cn", "Control"), ("control", "Control"),
  ("cr", "CR"), ("eb", "E_Base"), ("ebase", "E_Base"),
  ("ebasegaz", "E_Base_GAZ"), ("ebg", "E_Base_GAZ"), ("em", "E_Modifier"),
  ("emodifier", "E_Modifier"), ("ex", "Extend"), ("extend", "Extend"),
  ("gaz", "Glue_After_Zwj"), ("glueafterzwj", "Glue_After_Zwj"), ("l", "L"),
  ("lf", "LF"), ("lv", "LV"), ("lvt", "LVT"), ("other", "Other"),
  ("pp", "Prepend"), ("prepend", "Prepend"),
  ("regionalindicator", "Regional_Indicator"), ("ri", "Regional_Indicator"),
  ("sm", "SpacingMark"), ("spacingmark", "SpacingMark"), ("t", "T"),
  ("v", "V"), ("xx", "Other"), ("zwj", "ZWJ"), ]),

  ("Grapheme_Extend", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Grapheme_Link", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Hangul_Syllable_Type", &[("l", "Leading_Jamo"),
  ("leadingjamo", "Leading_Jamo"), ("lv", "LV_Syllable"),
  ("lvsyllable", "LV_Syllable"), ("lvt", "LVT_Syllable"),
  ("lvtsyllable", "LVT_Syllable"), ("na", "Not_Applicable"),
  ("notapplicable", "Not_Applicable"), ("t", "Trailing_Jamo"),
  ("trailingjamo", "Trailing_Jamo"), ("v", "Vowel_Jamo"),
  ("voweljamo", "Vowel_Jamo"), ]),

  ("Hex_Digit", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Hyphen", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("IDS_Binary_Operator", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("IDS_Trinary_Operator", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("ID_Continue", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("ID_Start", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Ideographic", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Indic_Positional_Category", &[("bottom", "Bottom"),
  ("bottomandleft", "Bottom_And_Left"),
  ("bottomandright", "Bottom_And_Right"), ("left", "Left"),
  ("leftandright", "Left_And_Right"), ("na", "NA"),
  ("overstruck", "Overstruck"), ("right", "Right"), ("top", "Top"),
  ("topandbottom", "Top_And_Bottom"),
  ("topandbottomandright", "Top_And_Bottom_And_Right"),
  ("topandleft", "Top_And_Left"),
  ("topandleftandright", "Top_And_Left_And_Right"),
  ("topandright", "Top_And_Right"), ("visualorderleft", "Visual_Order_Left"),
  ]),

  ("Indic_Syllabic_Category", &[("avagraha", "Avagraha"), ("bindu", "Bindu"),
  ("brahmijoiningnumber", "Brahmi_Joining_Number"),
  ("cantillationmark", "Cantillation_Mark"), ("consonant", "Consonant"),
  ("consonantdead", "Consonant_Dead"), ("consonantfinal", "Consonant_Final"),
  ("consonantheadletter", "Consonant_Head_Letter"),
  ("consonantinitialpostfixed", "Consonant_Initial_Postfixed"),
  ("consonantkiller", "Consonant_Killer"),
  ("consonantmedial", "Consonant_Medial"),
  ("consonantplaceholder", "Consonant_Placeholder"),
  ("consonantprecedingrepha", "Consonant_Preceding_Repha"),
  ("consonantprefixed", "Consonant_Prefixed"),
  ("consonantsubjoined", "Consonant_Subjoined"),
  ("consonantsucceedingrepha", "Consonant_Succeeding_Repha"),
  ("consonantwithstacker", "Consonant_With_Stacker"),
  ("geminationmark", "Gemination_Mark"),
  ("invisiblestacker", "Invisible_Stacker"), ("joiner", "Joiner"),
  ("modifyingletter", "Modifying_Letter"), ("nonjoiner", "Non_Joiner"),
  ("nukta", "Nukta"), ("number", "Number"), ("numberjoiner", "Number_Joiner"),
  ("other", "Other"), ("purekiller", "Pure_Killer"),
  ("registershifter", "Register_Shifter"),
  ("syllablemodifier", "Syllable_Modifier"), ("toneletter", "Tone_Letter"),
  ("tonemark", "Tone_Mark"), ("virama", "Virama"), ("visarga", "Visarga"),
  ("vowel", "Vowel"), ("voweldependent", "Vowel_Dependent"),
  ("vowelindependent", "Vowel_Independent"), ]),

  ("Jamo_Short_Name", &[("a", "A"), ("ae", "AE"), ("b", "B"), ("bb", "BB"),
  ("bs", "BS"), ("c", "C"), ("d", "D"), ("dd", "DD"), ("e", "E"),
  ("eo", "EO"), ("eu", "EU"), ("g", "G"), ("gg", "GG"), ("gs", "GS"),
  ("h", "H"), ("i", "I"), ("j", "J"), ("jj", "JJ"), ("k", "K"), ("l", "L"),
  ("lb", "LB"), ("lg", "LG"), ("lh", "LH"), ("lm", "LM"), ("lp", "LP"),
  ("ls", "LS"), ("lt", "LT"), ("m", "M"), ("n", "N"), ("ng", "NG"),
  ("nh", "NH"), ("nj", "NJ"), ("o", "O"), ("oe", "OE"), ("p", "P"),
  ("r", "R"), ("s", "S"), ("ss", "SS"), ("t", "T"), ("u", "U"), ("wa", "WA"),
  ("wae", "WAE"), ("we", "WE"), ("weo", "WEO"), ("wi", "WI"), ("ya", "YA"),
  ("yae", "YAE"), ("ye", "YE"), ("yeo", "YEO"), ("yi", "YI"), ("yo", "YO"),
  ("yu", "YU"), ]),

  ("Join_Control", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Joining_Group", &[("africanfeh", "African_Feh"),
  ("africannoon", "African_Noon"), ("africanqaf", "African_Qaf"),
  ("ain", "Ain"), ("alaph", "Alaph"), ("alef", "Alef"), ("beh", "Beh"),
  ("beth", "Beth"), ("burushaskiyehbarree", "Burushaski_Yeh_Barree"),
  ("dal", "Dal"), ("dalathrish", "Dalath_Rish"), ("e", "E"),
  ("farsiyeh", "Farsi_Yeh"), ("fe", "Fe"), ("feh", "Feh"),
  ("finalsemkath", "Final_Semkath"), ("gaf", "Gaf"), ("gamal", "Gamal"),
  ("hah", "Hah"), ("hamzaonhehgoal", "Hamza_On_Heh_Goal"),
  ("hanifirohingyakinnaya", "Hanifi_Rohingya_Kinna_Ya"),
  ("hanifirohingyapa", "Hanifi_Rohingya_Pa"), ("he", "He"), ("heh", "Heh"),
  ("hehgoal", "Heh_Goal"), ("heth", "Heth"), ("kaf", "Kaf"), ("kaph", "Kaph"),
  ("khaph", "Khaph"), ("knottedheh", "Knotted_Heh"), ("lam", "Lam"),
  ("lamadh", "Lamadh"), ("malayalambha", "Malayalam_Bha"),
  ("malayalamja", "Malayalam_Ja"), ("malayalamlla", "Malayalam_Lla"),
  ("malayalamllla", "Malayalam_Llla"), ("malayalamnga", "Malayalam_Nga"),
  ("malayalamnna", "Malayalam_Nna"), ("malayalamnnna", "Malayalam_Nnna"),
  ("malayalamnya", "Malayalam_Nya"), ("malayalamra", "Malayalam_Ra"),
  ("malayalamssa", "Malayalam_Ssa"), ("malayalamtta", "Malayalam_Tta"),
  ("manichaeanaleph", "Manichaean_Aleph"),
  ("manichaeanayin", "Manichaean_Ayin"),
  ("manichaeanbeth", "Manichaean_Beth"),
  ("manichaeandaleth", "Manichaean_Daleth"),
  ("manichaeandhamedh", "Manichaean_Dhamedh"),
  ("manichaeanfive", "Manichaean_Five"),
  ("manichaeangimel", "Manichaean_Gimel"),
  ("manichaeanheth", "Manichaean_Heth"),
  ("manichaeanhundred", "Manichaean_Hundred"),
  ("manichaeankaph", "Manichaean_Kaph"),
  ("manichaeanlamedh", "Manichaean_Lamedh"),
  ("manichaeanmem", "Manichaean_Mem"), ("manichaeannun", "Manichaean_Nun"),
  ("manichaeanone", "Manichaean_One"), ("manichaeanpe", "Manichaean_Pe"),
  ("manichaeanqoph", "Manichaean_Qoph"),
  ("manichaeanresh", "Manichaean_Resh"),
  ("manichaeansadhe", "Manichaean_Sadhe"),
  ("manichaeansamekh", "Manichaean_Samekh"),
  ("manichaeantaw", "Manichaean_Taw"), ("manichaeanten", "Manichaean_Ten"),
  ("manichaeanteth", "Manichaean_Teth"),
  ("manichaeanthamedh", "Manichaean_Thamedh"),
  ("manichaeantwenty", "Manichaean_Twenty"),
  ("manichaeanwaw", "Manichaean_Waw"), ("manichaeanyodh", "Manichaean_Yodh"),
  ("manichaeanzayin", "Manichaean_Zayin"), ("meem", "Meem"), ("mim", "Mim"),
  ("nojoininggroup", "No_Joining_Group"), ("noon", "Noon"), ("nun", "Nun"),
  ("nya", "Nya"), ("pe", "Pe"), ("qaf", "Qaf"), ("qaph", "Qaph"),
  ("reh", "Reh"), ("reversedpe", "Reversed_Pe"),
  ("rohingyayeh", "Rohingya_Yeh"), ("sad", "Sad"), ("sadhe", "Sadhe"),
  ("seen", "Seen"), ("semkath", "Semkath"), ("shin", "Shin"),
  ("straightwaw", "Straight_Waw"), ("swashkaf", "Swash_Kaf"),
  ("syriacwaw", "Syriac_Waw"), ("tah", "Tah"), ("taw", "Taw"),
  ("tehmarbuta", "Teh_Marbuta"), ("tehmarbutagoal", "Hamza_On_Heh_Goal"),
  ("teth", "Teth"), ("waw", "Waw"), ("yeh", "Yeh"),
  ("yehbarree", "Yeh_Barree"), ("yehwithtail", "Yeh_With_Tail"),
  ("yudh", "Yudh"), ("yudhhe", "Yudh_He"), ("zain", "Zain"),
  ("zhain", "Zhain"), ]),

  ("Joining_Type", &[("c", "Join_Causing"), ("d", "Dual_Joining"),
  ("dualjoining", "Dual_Joining"), ("joincausing", "Join_Causing"),
  ("l", "Left_Joining"), ("leftjoining", "Left_Joining"),
  ("nonjoining", "Non_Joining"), ("r", "Right_Joining"),
  ("rightjoining", "Right_Joining"), ("t", "Transparent"),
  ("transparent", "Transparent"), ("u", "Non_Joining"), ]),

  ("Line_Break", &[("", "Infix_Numeric"), ("ai", "Ambiguous"),
  ("al", "Alphabetic"), ("alphabetic", "Alphabetic"),
  ("ambiguous", "Ambiguous"), ("b2", "Break_Both"), ("ba", "Break_After"),
  ("bb", "Break_Before"), ("bk", "Mandatory_Break"),
  ("breakafter", "Break_After"), ("breakbefore", "Break_Before"),
  ("breakboth", "Break_Both"), ("breaksymbols", "Break_Symbols"),
  ("carriagereturn", "Carriage_Return"), ("cb", "Contingent_Break"),
  ("cj", "Conditional_Japanese_Starter"), ("cl", "Close_Punctuation"),
  ("closeparenthesis", "Close_Parenthesis"),
  ("closepunctuation", "Close_Punctuation"), ("cm", "Combining_Mark"),
  ("combiningmark", "Combining_Mark"), ("complexcontext", "Complex_Context"),
  ("conditionaljapanesestarter", "Conditional_Japanese_Starter"),
  ("contingentbreak", "Contingent_Break"), ("cp", "Close_Parenthesis"),
  ("cr", "Carriage_Return"), ("eb", "E_Base"), ("ebase", "E_Base"),
  ("em", "E_Modifier"), ("emodifier", "E_Modifier"), ("ex", "Exclamation"),
  ("exclamation", "Exclamation"), ("gl", "Glue"), ("glue", "Glue"),
  ("h2", "H2"), ("h3", "H3"), ("hebrewletter", "Hebrew_Letter"),
  ("hl", "Hebrew_Letter"), ("hy", "Hyphen"), ("hyphen", "Hyphen"),
  ("id", "Ideographic"), ("ideographic", "Ideographic"),
  ("in", "Inseparable"), ("infixnumeric", "Infix_Numeric"),
  ("inseparable", "Inseparable"), ("inseperable", "Inseparable"),
  ("jl", "JL"), ("jt", "JT"), ("jv", "JV"), ("lf", "Line_Feed"),
  ("linefeed", "Line_Feed"), ("mandatorybreak", "Mandatory_Break"),
  ("nextline", "Next_Line"), ("nl", "Next_Line"),
  ("nonstarter", "Nonstarter"), ("ns", "Nonstarter"), ("nu", "Numeric"),
  ("numeric", "Numeric"), ("op", "Open_Punctuation"),
  ("openpunctuation", "Open_Punctuation"), ("po", "Postfix_Numeric"),
  ("postfixnumeric", "Postfix_Numeric"), ("pr", "Prefix_Numeric"),
  ("prefixnumeric", "Prefix_Numeric"), ("qu", "Quotation"),
  ("quotation", "Quotation"), ("regionalindicator", "Regional_Indicator"),
  ("ri", "Regional_Indicator"), ("sa", "Complex_Context"),
  ("sg", "Surrogate"), ("sp", "Space"), ("space", "Space"),
  ("surrogate", "Surrogate"), ("sy", "Break_Symbols"), ("unknown", "Unknown"),
  ("wj", "Word_Joiner"), ("wordjoiner", "Word_Joiner"), ("xx", "Unknown"),
  ("zw", "ZWSpace"), ("zwj", "ZWJ"), ("zwspace", "ZWSpace"), ]),

  ("Logical_Order_Exception", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Lowercase", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Math", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("NFC_Quick_Check", &[("m", "Maybe"), ("maybe", "Maybe"), ("n", "No"),
  ("no", "No"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("NFD_Quick_Check", &[("n", "No"), ("no", "No"), ("y", "Yes"),
  ("yes", "Yes"), ]),

  ("NFKC_Quick_Check", &[("m", "Maybe"), ("maybe", "Maybe"), ("n", "No"),
  ("no", "No"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("NFKD_Quick_Check", &[("n", "No"), ("no", "No"), ("y", "Yes"),
  ("yes", "Yes"), ]),

  ("Noncharacter_Code_Point", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Numeric_Type", &[("de", "Decimal"), ("decimal", "Decimal"),
  ("di", "Digit"), ("digit", "Digit"), ("none", "None"), ("nu", "Numeric"),
  ("numeric", "Numeric"), ]),

  ("Other_Alphabetic", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Other_Default_Ignorable_Code_Point", &[("f", "No"), ("false", "No"),
  ("n", "No"), ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"),
  ("yes", "Yes"), ]),

  ("Other_Grapheme_Extend", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Other_ID_Continue", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Other_ID_Start", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Other_Lowercase", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Other_Math", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Other_Uppercase", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Pattern_Syntax", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Pattern_White_Space", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Prepended_Concatenation_Mark", &[("f", "No"), ("false", "No"),
  ("n", "No"), ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"),
  ("yes", "Yes"), ]),

  ("Quotation_Mark", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Radical", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Regional_Indicator", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Script", &[("adlam", "Adlam"), ("adlm", "Adlam"),
  ("aghb", "Caucasian_Albanian"), ("ahom", "Ahom"),
  ("anatolianhieroglyphs", "Anatolian_Hieroglyphs"), ("arab", "Arabic"),
  ("arabic", "Arabic"), ("armenian", "Armenian"),
  ("armi", "Imperial_Aramaic"), ("armn", "Armenian"), ("avestan", "Avestan"),
  ("avst", "Avestan"), ("bali", "Balinese"), ("balinese", "Balinese"),
  ("bamu", "Bamum"), ("bamum", "Bamum"), ("bass", "Bassa_Vah"),
  ("bassavah", "Bassa_Vah"), ("batak", "Batak"), ("batk", "Batak"),
  ("beng", "Bengali"), ("bengali", "Bengali"), ("bhaiksuki", "Bhaiksuki"),
  ("bhks", "Bhaiksuki"), ("bopo", "Bopomofo"), ("bopomofo", "Bopomofo"),
  ("brah", "Brahmi"), ("brahmi", "Brahmi"), ("brai", "Braille"),
  ("braille", "Braille"), ("bugi", "Buginese"), ("buginese", "Buginese"),
  ("buhd", "Buhid"), ("buhid", "Buhid"), ("cakm", "Chakma"),
  ("canadianaboriginal", "Canadian_Aboriginal"),
  ("cans", "Canadian_Aboriginal"), ("cari", "Carian"), ("carian", "Carian"),
  ("caucasianalbanian", "Caucasian_Albanian"), ("chakma", "Chakma"),
  ("cham", "Cham"), ("cher", "Cherokee"), ("cherokee", "Cherokee"),
  ("common", "Common"), ("copt", "Coptic"), ("coptic", "Coptic"),
  ("cprt", "Cypriot"), ("cuneiform", "Cuneiform"), ("cypriot", "Cypriot"),
  ("cyrillic", "Cyrillic"), ("cyrl", "Cyrillic"), ("deseret", "Deseret"),
  ("deva", "Devanagari"), ("devanagari", "Devanagari"), ("dogr", "Dogra"),
  ("dogra", "Dogra"), ("dsrt", "Deseret"), ("dupl", "Duployan"),
  ("duployan", "Duployan"), ("egyp", "Egyptian_Hieroglyphs"),
  ("egyptianhieroglyphs", "Egyptian_Hieroglyphs"), ("elba", "Elbasan"),
  ("elbasan", "Elbasan"), ("elym", "Elymaic"), ("elymaic", "Elymaic"),
  ("ethi", "Ethiopic"), ("ethiopic", "Ethiopic"), ("geor", "Georgian"),
  ("georgian", "Georgian"), ("glag", "Glagolitic"),
  ("glagolitic", "Glagolitic"), ("gong", "Gunjala_Gondi"),
  ("gonm", "Masaram_Gondi"), ("goth", "Gothic"), ("gothic", "Gothic"),
  ("gran", "Grantha"), ("grantha", "Grantha"), ("greek", "Greek"),
  ("grek", "Greek"), ("gujarati", "Gujarati"), ("gujr", "Gujarati"),
  ("gunjalagondi", "Gunjala_Gondi"), ("gurmukhi", "Gurmukhi"),
  ("guru", "Gurmukhi"), ("han", "Han"), ("hang", "Hangul"),
  ("hangul", "Hangul"), ("hani", "Han"),
  ("hanifirohingya", "Hanifi_Rohingya"), ("hano", "Hanunoo"),
  ("hanunoo", "Hanunoo"), ("hatr", "Hatran"), ("hatran", "Hatran"),
  ("hebr", "Hebrew"), ("hebrew", "Hebrew"), ("hira", "Hiragana"),
  ("hiragana", "Hiragana"), ("hluw", "Anatolian_Hieroglyphs"),
  ("hmng", "Pahawh_Hmong"), ("hmnp", "Nyiakeng_Puachue_Hmong"),
  ("hrkt", "Katakana_Or_Hiragana"), ("hung", "Old_Hungarian"),
  ("imperialaramaic", "Imperial_Aramaic"), ("inherited", "Inherited"),
  ("inscriptionalpahlavi", "Inscriptional_Pahlavi"),
  ("inscriptionalparthian", "Inscriptional_Parthian"), ("ital", "Old_Italic"),
  ("java", "Javanese"), ("javanese", "Javanese"), ("kaithi", "Kaithi"),
  ("kali", "Kayah_Li"), ("kana", "Katakana"), ("kannada", "Kannada"),
  ("katakana", "Katakana"), ("katakanaorhiragana", "Katakana_Or_Hiragana"),
  ("kayahli", "Kayah_Li"), ("khar", "Kharoshthi"),
  ("kharoshthi", "Kharoshthi"), ("khmer", "Khmer"), ("khmr", "Khmer"),
  ("khoj", "Khojki"), ("khojki", "Khojki"), ("khudawadi", "Khudawadi"),
  ("knda", "Kannada"), ("kthi", "Kaithi"), ("lana", "Tai_Tham"),
  ("lao", "Lao"), ("laoo", "Lao"), ("latin", "Latin"), ("latn", "Latin"),
  ("lepc", "Lepcha"), ("lepcha", "Lepcha"), ("limb", "Limbu"),
  ("limbu", "Limbu"), ("lina", "Linear_A"), ("linb", "Linear_B"),
  ("lineara", "Linear_A"), ("linearb", "Linear_B"), ("lisu", "Lisu"),
  ("lyci", "Lycian"), ("lycian", "Lycian"), ("lydi", "Lydian"),
  ("lydian", "Lydian"), ("mahajani", "Mahajani"), ("mahj", "Mahajani"),
  ("maka", "Makasar"), ("makasar", "Makasar"), ("malayalam", "Malayalam"),
  ("mand", "Mandaic"), ("mandaic", "Mandaic"), ("mani", "Manichaean"),
  ("manichaean", "Manichaean"), ("marc", "Marchen"), ("marchen", "Marchen"),
  ("masaramgondi", "Masaram_Gondi"), ("medefaidrin", "Medefaidrin"),
  ("medf", "Medefaidrin"), ("meeteimayek", "Meetei_Mayek"),
  ("mend", "Mende_Kikakui"), ("mendekikakui", "Mende_Kikakui"),
  ("merc", "Meroitic_Cursive"), ("mero", "Meroitic_Hieroglyphs"),
  ("meroiticcursive", "Meroitic_Cursive"),
  ("meroitichieroglyphs", "Meroitic_Hieroglyphs"), ("miao", "Miao"),
  ("mlym", "Malayalam"), ("modi", "Modi"), ("mong", "Mongolian"),
  ("mongolian", "Mongolian"), ("mro", "Mro"), ("mroo", "Mro"),
  ("mtei", "Meetei_Mayek"), ("mult", "Multani"), ("multani", "Multani"),
  ("myanmar", "Myanmar"), ("mymr", "Myanmar"), ("nabataean", "Nabataean"),
  ("nand", "Nandinagari"), ("nandinagari", "Nandinagari"),
  ("narb", "Old_North_Arabian"), ("nbat", "Nabataean"), ("newa", "Newa"),
  ("newtailue", "New_Tai_Lue"), ("nko", "Nko"), ("nkoo", "Nko"),
  ("nshu", "Nushu"), ("nushu", "Nushu"),
  ("nyiakengpuachuehmong", "Nyiakeng_Puachue_Hmong"), ("ogam", "Ogham"),
  ("ogham", "Ogham"), ("olchiki", "Ol_Chiki"), ("olck", "Ol_Chiki"),
  ("oldhungarian", "Old_Hungarian"), ("olditalic", "Old_Italic"),
  ("oldnortharabian", "Old_North_Arabian"), ("oldpermic", "Old_Permic"),
  ("oldpersian", "Old_Persian"), ("oldsogdian", "Old_Sogdian"),
  ("oldsoutharabian", "Old_South_Arabian"), ("oldturkic", "Old_Turkic"),
  ("oriya", "Oriya"), ("orkh", "Old_Turkic"), ("orya", "Oriya"),
  ("osage", "Osage"), ("osge", "Osage"), ("osma", "Osmanya"),
  ("osmanya", "Osmanya"), ("pahawhhmong", "Pahawh_Hmong"),
  ("palm", "Palmyrene"), ("palmyrene", "Palmyrene"), ("pauc", "Pau_Cin_Hau"),
  ("paucinhau", "Pau_Cin_Hau"), ("perm", "Old_Permic"), ("phag", "Phags_Pa"),
  ("phagspa", "Phags_Pa"), ("phli", "Inscriptional_Pahlavi"),
  ("phlp", "Psalter_Pahlavi"), ("phnx", "Phoenician"),
  ("phoenician", "Phoenician"), ("plrd", "Miao"),
  ("prti", "Inscriptional_Parthian"), ("psalterpahlavi", "Psalter_Pahlavi"),
  ("qaac", "Coptic"), ("qaai", "Inherited"), ("rejang", "Rejang"),
  ("rjng", "Rejang"), ("rohg", "Hanifi_Rohingya"), ("runic", "Runic"),
  ("runr", "Runic"), ("samaritan", "Samaritan"), ("samr", "Samaritan"),
  ("sarb", "Old_South_Arabian"), ("saur", "Saurashtra"),
  ("saurashtra", "Saurashtra"), ("sgnw", "SignWriting"),
  ("sharada", "Sharada"), ("shavian", "Shavian"), ("shaw", "Shavian"),
  ("shrd", "Sharada"), ("sidd", "Siddham"), ("siddham", "Siddham"),
  ("signwriting", "SignWriting"), ("sind", "Khudawadi"), ("sinh", "Sinhala"),
  ("sinhala", "Sinhala"), ("sogd", "Sogdian"), ("sogdian", "Sogdian"),
  ("sogo", "Old_Sogdian"), ("sora", "Sora_Sompeng"),
  ("sorasompeng", "Sora_Sompeng"), ("soyo", "Soyombo"),
  ("soyombo", "Soyombo"), ("sund", "Sundanese"), ("sundanese", "Sundanese"),
  ("sylo", "Syloti_Nagri"), ("sylotinagri", "Syloti_Nagri"),
  ("syrc", "Syriac"), ("syriac", "Syriac"), ("tagalog", "Tagalog"),
  ("tagb", "Tagbanwa"), ("tagbanwa", "Tagbanwa"), ("taile", "Tai_Le"),
  ("taitham", "Tai_Tham"), ("taiviet", "Tai_Viet"), ("takr", "Takri"),
  ("takri", "Takri"), ("tale", "Tai_Le"), ("talu", "New_Tai_Lue"),
  ("tamil", "Tamil"), ("taml", "Tamil"), ("tang", "Tangut"),
  ("tangut", "Tangut"), ("tavt", "Tai_Viet"), ("telu", "Telugu"),
  ("telugu", "Telugu"), ("tfng", "Tifinagh"), ("tglg", "Tagalog"),
  ("thaa", "Thaana"), ("thaana", "Thaana"), ("thai", "Thai"),
  ("tibetan", "Tibetan"), ("tibt", "Tibetan"), ("tifinagh", "Tifinagh"),
  ("tirh", "Tirhuta"), ("tirhuta", "Tirhuta"), ("ugar", "Ugaritic"),
  ("ugaritic", "Ugaritic"), ("unknown", "Unknown"), ("vai", "Vai"),
  ("vaii", "Vai"), ("wancho", "Wancho"), ("wara", "Warang_Citi"),
  ("warangciti", "Warang_Citi"), ("wcho", "Wancho"), ("xpeo", "Old_Persian"),
  ("xsux", "Cuneiform"), ("yi", "Yi"), ("yiii", "Yi"),
  ("zanabazarsquare", "Zanabazar_Square"), ("zanb", "Zanabazar_Square"),
  ("zinh", "Inherited"), ("zyyy", "Common"), ("zzzz", "Unknown"), ]),

  ("Script_Extensions", &[("adlam", "Adlam"), ("adlm", "Adlam"),
  ("aghb", "Caucasian_Albanian"), ("ahom", "Ahom"),
  ("anatolianhieroglyphs", "Anatolian_Hieroglyphs"), ("arab", "Arabic"),
  ("arabic", "Arabic"), ("armenian", "Armenian"),
  ("armi", "Imperial_Aramaic"), ("armn", "Armenian"), ("avestan", "Avestan"),
  ("avst", "Avestan"), ("bali", "Balinese"), ("balinese", "Balinese"),
  ("bamu", "Bamum"), ("bamum", "Bamum"), ("bass", "Bassa_Vah"),
  ("bassavah", "Bassa_Vah"), ("batak", "Batak"), ("batk", "Batak"),
  ("beng", "Bengali"), ("bengali", "Bengali"), ("bhaiksuki", "Bhaiksuki"),
  ("bhks", "Bhaiksuki"), ("bopo", "Bopomofo"), ("bopomofo", "Bopomofo"),
  ("brah", "Brahmi"), ("brahmi", "Brahmi"), ("brai", "Braille"),
  ("braille", "Braille"), ("bugi", "Buginese"), ("buginese", "Buginese"),
  ("buhd", "Buhid"), ("buhid", "Buhid"), ("cakm", "Chakma"),
  ("canadianaboriginal", "Canadian_Aboriginal"),
  ("cans", "Canadian_Aboriginal"), ("cari", "Carian"), ("carian", "Carian"),
  ("caucasianalbanian", "Caucasian_Albanian"), ("chakma", "Chakma"),
  ("cham", "Cham"), ("cher", "Cherokee"), ("cherokee", "Cherokee"),
  ("common", "Common"), ("copt", "Coptic"), ("coptic", "Coptic"),
  ("cprt", "Cypriot"), ("cuneiform", "Cuneiform"), ("cypriot", "Cypriot"),
  ("cyrillic", "Cyrillic"), ("cyrl", "Cyrillic"), ("deseret", "Deseret"),
  ("deva", "Devanagari"), ("devanagari", "Devanagari"), ("dogr", "Dogra"),
  ("dogra", "Dogra"), ("dsrt", "Deseret"), ("dupl", "Duployan"),
  ("duployan", "Duployan"), ("egyp", "Egyptian_Hieroglyphs"),
  ("egyptianhieroglyphs", "Egyptian_Hieroglyphs"), ("elba", "Elbasan"),
  ("elbasan", "Elbasan"), ("elym", "Elymaic"), ("elymaic", "Elymaic"),
  ("ethi", "Ethiopic"), ("ethiopic", "Ethiopic"), ("geor", "Georgian"),
  ("georgian", "Georgian"), ("glag", "Glagolitic"),
  ("glagolitic", "Glagolitic"), ("gong", "Gunjala_Gondi"),
  ("gonm", "Masaram_Gondi"), ("goth", "Gothic"), ("gothic", "Gothic"),
  ("gran", "Grantha"), ("grantha", "Grantha"), ("greek", "Greek"),
  ("grek", "Greek"), ("gujarati", "Gujarati"), ("gujr", "Gujarati"),
  ("gunjalagondi", "Gunjala_Gondi"), ("gurmukhi", "Gurmukhi"),
  ("guru", "Gurmukhi"), ("han", "Han"), ("hang", "Hangul"),
  ("hangul", "Hangul"), ("hani", "Han"),
  ("hanifirohingya", "Hanifi_Rohingya"), ("hano", "Hanunoo"),
  ("hanunoo", "Hanunoo"), ("hatr", "Hatran"), ("hatran", "Hatran"),
  ("hebr", "Hebrew"), ("hebrew", "Hebrew"), ("hira", "Hiragana"),
  ("hiragana", "Hiragana"), ("hluw", "Anatolian_Hieroglyphs"),
  ("hmng", "Pahawh_Hmong"), ("hmnp", "Nyiakeng_Puachue_Hmong"),
  ("hrkt", "Katakana_Or_Hiragana"), ("hung", "Old_Hungarian"),
  ("imperialaramaic", "Imperial_Aramaic"), ("inherited", "Inherited"),
  ("inscriptionalpahlavi", "Inscriptional_Pahlavi"),
  ("inscriptionalparthian", "Inscriptional_Parthian"), ("ital", "Old_Italic"),
  ("java", "Javanese"), ("javanese", "Javanese"), ("kaithi", "Kaithi"),
  ("kali", "Kayah_Li"), ("kana", "Katakana"), ("kannada", "Kannada"),
  ("katakana", "Katakana"), ("katakanaorhiragana", "Katakana_Or_Hiragana"),
  ("kayahli", "Kayah_Li"), ("khar", "Kharoshthi"),
  ("kharoshthi", "Kharoshthi"), ("khmer", "Khmer"), ("khmr", "Khmer"),
  ("khoj", "Khojki"), ("khojki", "Khojki"), ("khudawadi", "Khudawadi"),
  ("knda", "Kannada"), ("kthi", "Kaithi"), ("lana", "Tai_Tham"),
  ("lao", "Lao"), ("laoo", "Lao"), ("latin", "Latin"), ("latn", "Latin"),
  ("lepc", "Lepcha"), ("lepcha", "Lepcha"), ("limb", "Limbu"),
  ("limbu", "Limbu"), ("lina", "Linear_A"), ("linb", "Linear_B"),
  ("lineara", "Linear_A"), ("linearb", "Linear_B"), ("lisu", "Lisu"),
  ("lyci", "Lycian"), ("lycian", "Lycian"), ("lydi", "Lydian"),
  ("lydian", "Lydian"), ("mahajani", "Mahajani"), ("mahj", "Mahajani"),
  ("maka", "Makasar"), ("makasar", "Makasar"), ("malayalam", "Malayalam"),
  ("mand", "Mandaic"), ("mandaic", "Mandaic"), ("mani", "Manichaean"),
  ("manichaean", "Manichaean"), ("marc", "Marchen"), ("marchen", "Marchen"),
  ("masaramgondi", "Masaram_Gondi"), ("medefaidrin", "Medefaidrin"),
  ("medf", "Medefaidrin"), ("meeteimayek", "Meetei_Mayek"),
  ("mend", "Mende_Kikakui"), ("mendekikakui", "Mende_Kikakui"),
  ("merc", "Meroitic_Cursive"), ("mero", "Meroitic_Hieroglyphs"),
  ("meroiticcursive", "Meroitic_Cursive"),
  ("meroitichieroglyphs", "Meroitic_Hieroglyphs"), ("miao", "Miao"),
  ("mlym", "Malayalam"), ("modi", "Modi"), ("mong", "Mongolian"),
  ("mongolian", "Mongolian"), ("mro", "Mro"), ("mroo", "Mro"),
  ("mtei", "Meetei_Mayek"), ("mult", "Multani"), ("multani", "Multani"),
  ("myanmar", "Myanmar"), ("mymr", "Myanmar"), ("nabataean", "Nabataean"),
  ("nand", "Nandinagari"), ("nandinagari", "Nandinagari"),
  ("narb", "Old_North_Arabian"), ("nbat", "Nabataean"), ("newa", "Newa"),
  ("newtailue", "New_Tai_Lue"), ("nko", "Nko"), ("nkoo", "Nko"),
  ("nshu", "Nushu"), ("nushu", "Nushu"),
  ("nyiakengpuachuehmong", "Nyiakeng_Puachue_Hmong"), ("ogam", "Ogham"),
  ("ogham", "Ogham"), ("olchiki", "Ol_Chiki"), ("olck", "Ol_Chiki"),
  ("oldhungarian", "Old_Hungarian"), ("olditalic", "Old_Italic"),
  ("oldnortharabian", "Old_North_Arabian"), ("oldpermic", "Old_Permic"),
  ("oldpersian", "Old_Persian"), ("oldsogdian", "Old_Sogdian"),
  ("oldsoutharabian", "Old_South_Arabian"), ("oldturkic", "Old_Turkic"),
  ("oriya", "Oriya"), ("orkh", "Old_Turkic"), ("orya", "Oriya"),
  ("osage", "Osage"), ("osge", "Osage"), ("osma", "Osmanya"),
  ("osmanya", "Osmanya"), ("pahawhhmong", "Pahawh_Hmong"),
  ("palm", "Palmyrene"), ("palmyrene", "Palmyrene"), ("pauc", "Pau_Cin_Hau"),
  ("paucinhau", "Pau_Cin_Hau"), ("perm", "Old_Permic"), ("phag", "Phags_Pa"),
  ("phagspa", "Phags_Pa"), ("phli", "Inscriptional_Pahlavi"),
  ("phlp", "Psalter_Pahlavi"), ("phnx", "Phoenician"),
  ("phoenician", "Phoenician"), ("plrd", "Miao"),
  ("prti", "Inscriptional_Parthian"), ("psalterpahlavi", "Psalter_Pahlavi"),
  ("qaac", "Coptic"), ("qaai", "Inherited"), ("rejang", "Rejang"),
  ("rjng", "Rejang"), ("rohg", "Hanifi_Rohingya"), ("runic", "Runic"),
  ("runr", "Runic"), ("samaritan", "Samaritan"), ("samr", "Samaritan"),
  ("sarb", "Old_South_Arabian"), ("saur", "Saurashtra"),
  ("saurashtra", "Saurashtra"), ("sgnw", "SignWriting"),
  ("sharada", "Sharada"), ("shavian", "Shavian"), ("shaw", "Shavian"),
  ("shrd", "Sharada"), ("sidd", "Siddham"), ("siddham", "Siddham"),
  ("signwriting", "SignWriting"), ("sind", "Khudawadi"), ("sinh", "Sinhala"),
  ("sinhala", "Sinhala"), ("sogd", "Sogdian"), ("sogdian", "Sogdian"),
  ("sogo", "Old_Sogdian"), ("sora", "Sora_Sompeng"),
  ("sorasompeng", "Sora_Sompeng"), ("soyo", "Soyombo"),
  ("soyombo", "Soyombo"), ("sund", "Sundanese"), ("sundanese", "Sundanese"),
  ("sylo", "Syloti_Nagri"), ("sylotinagri", "Syloti_Nagri"),
  ("syrc", "Syriac"), ("syriac", "Syriac"), ("tagalog", "Tagalog"),
  ("tagb", "Tagbanwa"), ("tagbanwa", "Tagbanwa"), ("taile", "Tai_Le"),
  ("taitham", "Tai_Tham"), ("taiviet", "Tai_Viet"), ("takr", "Takri"),
  ("takri", "Takri"), ("tale", "Tai_Le"), ("talu", "New_Tai_Lue"),
  ("tamil", "Tamil"), ("taml", "Tamil"), ("tang", "Tangut"),
  ("tangut", "Tangut"), ("tavt", "Tai_Viet"), ("telu", "Telugu"),
  ("telugu", "Telugu"), ("tfng", "Tifinagh"), ("tglg", "Tagalog"),
  ("thaa", "Thaana"), ("thaana", "Thaana"), ("thai", "Thai"),
  ("tibetan", "Tibetan"), ("tibt", "Tibetan"), ("tifinagh", "Tifinagh"),
  ("tirh", "Tirhuta"), ("tirhuta", "Tirhuta"), ("ugar", "Ugaritic"),
  ("ugaritic", "Ugaritic"), ("unknown", "Unknown"), ("vai", "Vai"),
  ("vaii", "Vai"), ("wancho", "Wancho"), ("wara", "Warang_Citi"),
  ("warangciti", "Warang_Citi"), ("wcho", "Wancho"), ("xpeo", "Old_Persian"),
  ("xsux", "Cuneiform"), ("yi", "Yi"), ("yiii", "Yi"),
  ("zanabazarsquare", "Zanabazar_Square"), ("zanb", "Zanabazar_Square"),
  ("zinh", "Inherited"), ("zyyy", "Common"), ("zzzz", "Unknown"), ]),

  ("Sentence_Break", &[("at", "ATerm"), ("aterm", "ATerm"), ("cl", "Close"),
  ("close", "Close"), ("cr", "CR"), ("ex", "Extend"), ("extend", "Extend"),
  ("fo", "Format"), ("format", "Format"), ("le", "OLetter"), ("lf", "LF"),
  ("lo", "Lower"), ("lower", "Lower"), ("nu", "Numeric"),
  ("numeric", "Numeric"), ("oletter", "OLetter"), ("other", "Other"),
  ("sc", "SContinue"), ("scontinue", "SContinue"), ("se", "Sep"),
  ("sep", "Sep"), ("sp", "Sp"), ("st", "STerm"), ("sterm", "STerm"),
  ("up", "Upper"), ("upper", "Upper"), ("xx", "Other"), ]),

  ("Sentence_Terminal", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Soft_Dotted", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Terminal_Punctuation", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Unified_Ideograph", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Uppercase", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Variation_Selector", &[("f", "No"), ("false", "No"), ("n", "No"),
  ("no", "No"), ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"),
  ]),

  ("Vertical_Orientation", &[("r", "Rotated"), ("rotated", "Rotated"),
  ("tr", "Transformed_Rotated"),
  ("transformedrotated", "Transformed_Rotated"),
  ("transformedupright", "Transformed_Upright"),
  ("tu", "Transformed_Upright"), ("u", "Upright"), ("upright", "Upright"), ]),

  ("White_Space", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("Word_Break", &[("aletter", "ALetter"), ("cr", "CR"),
  ("doublequote", "Double_Quote"), ("dq", "Double_Quote"), ("eb", "E_Base"),
  ("ebase", "E_Base"), ("ebasegaz", "E_Base_GAZ"), ("ebg", "E_Base_GAZ"),
  ("em", "E_Modifier"), ("emodifier", "E_Modifier"), ("ex", "ExtendNumLet"),
  ("extend", "Extend"), ("extendnumlet", "ExtendNumLet"), ("fo", "Format"),
  ("format", "Format"), ("gaz", "Glue_After_Zwj"),
  ("glueafterzwj", "Glue_After_Zwj"), ("hebrewletter", "Hebrew_Letter"),
  ("hl", "Hebrew_Letter"), ("ka", "Katakana"), ("katakana", "Katakana"),
  ("le", "ALetter"), ("lf", "LF"), ("mb", "MidNumLet"),
  ("midletter", "MidLetter"), ("midnum", "MidNum"),
  ("midnumlet", "MidNumLet"), ("ml", "MidLetter"), ("mn", "MidNum"),
  ("newline", "Newline"), ("nl", "Newline"), ("nu", "Numeric"),
  ("numeric", "Numeric"), ("other", "Other"),
  ("regionalindicator", "Regional_Indicator"), ("ri", "Regional_Indicator"),
  ("singlequote", "Single_Quote"), ("sq", "Single_Quote"),
  ("wsegspace", "WSegSpace"), ("xx", "Other"), ("zwj", "ZWJ"), ]),

  ("XID_Continue", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),

  ("XID_Start", &[("f", "No"), ("false", "No"), ("n", "No"), ("no", "No"),
  ("t", "Yes"), ("true", "Yes"), ("y", "Yes"), ("yes", "Yes"), ]),
];
