// DO NOT EDIT THIS FILE. IT WAS AUTOMATICALLY GENERATED BY:
//
//  ucd-generate property-names /home/andrew/tmp/ucd/12.1.0/
//
// ucd-generate is available on crates.io.

pub const PROPERTY_NAMES: &'static [(&'static str, &'static str)] = &[
  ("age", "Age"), ("ahex", "ASCII_Hex_Digit"), ("alpha", "Alphabetic"),
  ("alphabetic", "Alphabetic"), ("asciihexdigit", "ASCII_Hex_Digit"),
  ("bc", "Bidi_Class"), ("bidic", "Bidi_Control"),
  ("bidiclass", "Bidi_Class"), ("bidicontrol", "Bidi_Control"),
  ("bidim", "Bidi_Mirrored"), ("bidimirrored", "Bidi_Mirrored"),
  ("bidimirroringglyph", "Bidi_Mirroring_Glyph"),
  ("bidipairedbracket", "Bidi_Paired_Bracket"),
  ("bidipairedbrackettype", "Bidi_Paired_Bracket_Type"), ("blk", "Block"),
  ("block", "Block"), ("bmg", "Bidi_Mirroring_Glyph"),
  ("bpb", "Bidi_Paired_Bracket"), ("bpt", "Bidi_Paired_Bracket_Type"),
  ("canonicalcombiningclass", "Canonical_Combining_Class"),
  ("cased", "Cased"), ("casefolding", "Case_Folding"),
  ("caseignorable", "Case_Ignorable"), ("ccc", "Canonical_Combining_Class"),
  ("ce", "Composition_Exclusion"), ("cf", "Case_Folding"),
  ("changeswhencasefolded", "Changes_When_Casefolded"),
  ("changeswhencasemapped", "Changes_When_Casemapped"),
  ("changeswhenlowercased", "Changes_When_Lowercased"),
  ("changeswhennfkccasefolded", "Changes_When_NFKC_Casefolded"),
  ("changeswhentitlecased", "Changes_When_Titlecased"),
  ("changeswhenuppercased", "Changes_When_Uppercased"),
  ("ci", "Case_Ignorable"), ("cjkaccountingnumeric", "kAccountingNumeric"),
  ("cjkcompatibilityvariant", "kCompatibilityVariant"),
  ("cjkiicore", "kIICore"), ("cjkirggsource", "kIRG_GSource"),
  ("cjkirghsource", "kIRG_HSource"), ("cjkirgjsource", "kIRG_JSource"),
  ("cjkirgkpsource", "kIRG_KPSource"), ("cjkirgksource", "kIRG_KSource"),
  ("cjkirgmsource", "kIRG_MSource"), ("cjkirgtsource", "kIRG_TSource"),
  ("cjkirgusource", "kIRG_USource"), ("cjkirgvsource", "kIRG_VSource"),
  ("cjkothernumeric", "kOtherNumeric"),
  ("cjkprimarynumeric", "kPrimaryNumeric"), ("cjkrsunicode", "kRSUnicode"),
  ("compex", "Full_Composition_Exclusion"),
  ("compositionexclusion", "Composition_Exclusion"),
  ("cwcf", "Changes_When_Casefolded"), ("cwcm", "Changes_When_Casemapped"),
  ("cwkcf", "Changes_When_NFKC_Casefolded"),
  ("cwl", "Changes_When_Lowercased"), ("cwt", "Changes_When_Titlecased"),
  ("cwu", "Changes_When_Uppercased"), ("dash", "Dash"),
  ("decompositionmapping", "Decomposition_Mapping"),
  ("decompositiontype", "Decomposition_Type"),
  ("defaultignorablecodepoint", "Default_Ignorable_Code_Point"),
  ("dep", "Deprecated"), ("deprecated", "Deprecated"),
  ("di", "Default_Ignorable_Code_Point"), ("dia", "Diacritic"),
  ("diacritic", "Diacritic"), ("dm", "Decomposition_Mapping"),
  ("dt", "Decomposition_Type"), ("ea", "East_Asian_Width"),
  ("eastasianwidth", "East_Asian_Width"), ("emoji", "Emoji"),
  ("emojicomponent", "Emoji_Component"), ("emojimodifier", "Emoji_Modifier"),
  ("emojimodifierbase", "Emoji_Modifier_Base"),
  ("emojipresentation", "Emoji_Presentation"),
  ("equideo", "Equivalent_Unified_Ideograph"),
  ("equivalentunifiedideograph", "Equivalent_Unified_Ideograph"),
  ("expandsonnfc", "Expands_On_NFC"), ("expandsonnfd", "Expands_On_NFD"),
  ("expandsonnfkc", "Expands_On_NFKC"), ("expandsonnfkd", "Expands_On_NFKD"),
  ("ext", "Extender"), ("extendedpictographic", "Extended_Pictographic"),
  ("extender", "Extender"), ("fcnfkc", "FC_NFKC_Closure"),
  ("fcnfkcclosure", "FC_NFKC_Closure"),
  ("fullcompositionexclusion", "Full_Composition_Exclusion"),
  ("gc", "General_Category"), ("gcb", "Grapheme_Cluster_Break"),
  ("generalcategory", "General_Category"), ("graphemebase", "Grapheme_Base"),
  ("graphemeclusterbreak", "Grapheme_Cluster_Break"),
  ("graphemeextend", "Grapheme_Extend"), ("graphemelink", "Grapheme_Link"),
  ("grbase", "Grapheme_Base"), ("grext", "Grapheme_Extend"),
  ("grlink", "Grapheme_Link"), ("hangulsyllabletype", "Hangul_Syllable_Type"),
  ("hex", "Hex_Digit"), ("hexdigit", "Hex_Digit"),
  ("hst", "Hangul_Syllable_Type"), ("hyphen", "Hyphen"),
  ("idc", "ID_Continue"), ("idcontinue", "ID_Continue"),
  ("ideo", "Ideographic"), ("ideographic", "Ideographic"),
  ("ids", "ID_Start"), ("idsb", "IDS_Binary_Operator"),
  ("idsbinaryoperator", "IDS_Binary_Operator"),
  ("idst", "IDS_Trinary_Operator"), ("idstart", "ID_Start"),
  ("idstrinaryoperator", "IDS_Trinary_Operator"),
  ("indicpositionalcategory", "Indic_Positional_Category"),
  ("indicsyllabiccategory", "Indic_Syllabic_Category"),
  ("inpc", "Indic_Positional_Category"), ("insc", "Indic_Syllabic_Category"),
  ("isc", "ISO_Comment"), ("jamoshortname", "Jamo_Short_Name"),
  ("jg", "Joining_Group"), ("joinc", "Join_Control"),
  ("joincontrol", "Join_Control"), ("joininggroup", "Joining_Group"),
  ("joiningtype", "Joining_Type"), ("jsn", "Jamo_Short_Name"),
  ("jt", "Joining_Type"), ("kaccountingnumeric", "kAccountingNumeric"),
  ("kcompatibilityvariant", "kCompatibilityVariant"), ("kiicore", "kIICore"),
  ("kirggsource", "kIRG_GSource"), ("kirghsource", "kIRG_HSource"),
  ("kirgjsource", "kIRG_JSource"), ("kirgkpsource", "kIRG_KPSource"),
  ("kirgksource", "kIRG_KSource"), ("kirgmsource", "kIRG_MSource"),
  ("kirgtsource", "kIRG_TSource"), ("kirgusource", "kIRG_USource"),
  ("kirgvsource", "kIRG_VSource"), ("kothernumeric", "kOtherNumeric"),
  ("kprimarynumeric", "kPrimaryNumeric"), ("krsunicode", "kRSUnicode"),
  ("lb", "Line_Break"), ("lc", "Lowercase_Mapping"),
  ("linebreak", "Line_Break"), ("loe", "Logical_Order_Exception"),
  ("logicalorderexception", "Logical_Order_Exception"),
  ("lower", "Lowercase"), ("lowercase", "Lowercase"),
  ("lowercasemapping", "Lowercase_Mapping"), ("math", "Math"), ("na", "Name"),
  ("na1", "Unicode_1_Name"), ("name", "Name"), ("namealias", "Name_Alias"),
  ("nchar", "Noncharacter_Code_Point"), ("nfcqc", "NFC_Quick_Check"),
  ("nfcquickcheck", "NFC_Quick_Check"), ("nfdqc", "NFD_Quick_Check"),
  ("nfdquickcheck", "NFD_Quick_Check"), ("nfkccasefold", "NFKC_Casefold"),
  ("nfkccf", "NFKC_Casefold"), ("nfkcqc", "NFKC_Quick_Check"),
  ("nfkcquickcheck", "NFKC_Quick_Check"), ("nfkdqc", "NFKD_Quick_Check"),
  ("nfkdquickcheck", "NFKD_Quick_Check"),
  ("noncharactercodepoint", "Noncharacter_Code_Point"),
  ("nt", "Numeric_Type"), ("numerictype", "Numeric_Type"),
  ("numericvalue", "Numeric_Value"), ("nv", "Numeric_Value"),
  ("oalpha", "Other_Alphabetic"), ("ocomment", "ISO_Comment"),
  ("odi", "Other_Default_Ignorable_Code_Point"),
  ("ogrext", "Other_Grapheme_Extend"), ("oidc", "Other_ID_Continue"),
  ("oids", "Other_ID_Start"), ("olower", "Other_Lowercase"),
  ("omath", "Other_Math"), ("otheralphabetic", "Other_Alphabetic"),
  ("otherdefaultignorablecodepoint", "Other_Default_Ignorable_Code_Point"),
  ("othergraphemeextend", "Other_Grapheme_Extend"),
  ("otheridcontinue", "Other_ID_Continue"),
  ("otheridstart", "Other_ID_Start"), ("otherlowercase", "Other_Lowercase"),
  ("othermath", "Other_Math"), ("otheruppercase", "Other_Uppercase"),
  ("oupper", "Other_Uppercase"), ("patsyn", "Pattern_Syntax"),
  ("patternsyntax", "Pattern_Syntax"),
  ("patternwhitespace", "Pattern_White_Space"),
  ("patws", "Pattern_White_Space"), ("pcm", "Prepended_Concatenation_Mark"),
  ("prependedconcatenationmark", "Prepended_Concatenation_Mark"),
  ("qmark", "Quotation_Mark"), ("quotationmark", "Quotation_Mark"),
  ("radical", "Radical"), ("regionalindicator", "Regional_Indicator"),
  ("ri", "Regional_Indicator"), ("sb", "Sentence_Break"), ("sc", "Script"),
  ("scf", "Simple_Case_Folding"), ("script", "Script"),
  ("scriptextensions", "Script_Extensions"), ("scx", "Script_Extensions"),
  ("sd", "Soft_Dotted"), ("sentencebreak", "Sentence_Break"),
  ("sentenceterminal", "Sentence_Terminal"), ("sfc", "Simple_Case_Folding"),
  ("simplecasefolding", "Simple_Case_Folding"),
  ("simplelowercasemapping", "Simple_Lowercase_Mapping"),
  ("simpletitlecasemapping", "Simple_Titlecase_Mapping"),
  ("simpleuppercasemapping", "Simple_Uppercase_Mapping"),
  ("slc", "Simple_Lowercase_Mapping"), ("softdotted", "Soft_Dotted"),
  ("space", "White_Space"), ("stc", "Simple_Titlecase_Mapping"),
  ("sterm", "Sentence_Terminal"), ("suc", "Simple_Uppercase_Mapping"),
  ("tc", "Titlecase_Mapping"), ("term", "Terminal_Punctuation"),
  ("terminalpunctuation", "Terminal_Punctuation"),
  ("titlecasemapping", "Titlecase_Mapping"), ("uc", "Uppercase_Mapping"),
  ("uideo", "Unified_Ideograph"), ("unicode1name", "Unicode_1_Name"),
  ("unicoderadicalstroke", "kRSUnicode"),
  ("unifiedideograph", "Unified_Ideograph"), ("upper", "Uppercase"),
  ("uppercase", "Uppercase"), ("uppercasemapping", "Uppercase_Mapping"),
  ("urs", "kRSUnicode"), ("variationselector", "Variation_Selector"),
  ("verticalorientation", "Vertical_Orientation"),
  ("vo", "Vertical_Orientation"), ("vs", "Variation_Selector"),
  ("wb", "Word_Break"), ("whitespace", "White_Space"),
  ("wordbreak", "Word_Break"), ("wspace", "White_Space"),
  ("xidc", "XID_Continue"), ("xidcontinue", "XID_Continue"),
  ("xids", "XID_Start"), ("xidstart", "XID_Start"),
  ("xonfc", "Expands_On_NFC"), ("xonfd", "Expands_On_NFD"),
  ("xonfkc", "Expands_On_NFKC"), ("xonfkd", "Expands_On_NFKD"),
];
